@@ -14,6 +14,8 @@
 #include <QString>
 #include <QStringList>
 #include <QObject>
+#include <QtQml/qqmlregistration.h>
+#include <config.h>
 
 /**
  * @class Directory
@@ -23,7 +25,9 @@
 class Directory : public QObject
 {
     Q_OBJECT
-
+#ifndef WITH_RCC
+    QML_ELEMENT
+#endif
 public:
     /**
      * Constructor
